<?php
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: health.proto

namespace GPBMetadata;

class Health
{
    public static $is_initialized = false;

    public static function initOnce() {
        $pool = \Google\Protobuf\Internal\DescriptorPool::getGeneratedPool();

        if (static::$is_initialized == true) {
          return;
        }
        \GPBMetadata\Device::initOnce();
        \GPBMetadata\Types::initOnce();
        $pool->internalAddGeneratedFile(
            "\x0A\xA1\x01\x0A\x0Chealth.proto\x12\x05OS.PB\x1A\x0Btypes.proto\"C\x0A\x0BHealthEvent\x12\x0E\x0A\x06Serial\x18\x01 \x01(\x0D\x12\x0C\x0A\x04RSSI\x18\x05 \x01(\x11\x12\x16\x0A\x0EBatteryVoltage\x18\x06 \x01(\x0D\",\x0A\x0CHealthConfig\x12\x1C\x0A\x05State\x18\x01 \x01(\x0E2\x0D.OS.PB.ToggleB\x02H\x02b\x06proto3"
        , true);

        static::$is_initialized = true;
    }
}

